# 1. Sensor例程讲解

## 1. 概述

K230有3路MIPI-CSI（3x2 lane/1x4+1x2 lane）输入，最多可接3路摄像头，每路摄像头支持3个通道输出不同的分辨率及图像格式

## 2. 示例

### 2.1 获取单摄3个通道图像显示在HDMI显示器

打开摄像头，获取3个通道的图像显示在HDMI显示器

通道0采集1080P图像，通道1和通道2采集VGA分辨率图像并叠加在通道0图像上

```python
# Camera示例
import time, os, sys

from media.sensor import *
from media.display import *
from media.media import *

sensor = None

try:
    print("camera_test")

    # 按照默认配置构建Sensor对象
    sensor = Sensor()
    # sensor复位
    sensor.reset()
    # 设置水平镜像
    # sensor.set_hmirror(False)
    # 设置垂直翻转
    # sensor.set_vflip(False)

    # 设置通道0分辨率, 1920x1080
    sensor.set_framesize(Sensor.FHD)
    # 设置通道0格式
    sensor.set_pixformat(Sensor.YUV420SP)
    # 绑定通道0到显示VIDEO1层
    bind_info = sensor.bind_info()
    Display.bind_layer(**bind_info, layer = Display.LAYER_VIDEO1)

    # 设置通道1分辨率和格式
    sensor.set_framesize(width = 640, height = 480, chn = CAM_CHN_ID_1)
    sensor.set_pixformat(Sensor.RGB888, chn = CAM_CHN_ID_1)

    # 设置通道2分辨率和格式
    sensor.set_framesize(width = 640, height = 480, chn = CAM_CHN_ID_2)
    sensor.set_pixformat(Sensor.RGB565, chn = CAM_CHN_ID_2)

    # 这里设置hdmi和IDE输出显示，如果您选择的屏幕无法点亮，请参考API文档中的K230_CanMV_Display模块API手册自行配置
    Display.init(Display.LT9611, to_ide = True, osd_num = 2)
    # 初始化media manager
    MediaManager.init()
    # 启动sensor
    sensor.run()

    while True:
        os.exitpoint()

        img = sensor.snapshot(chn = CAM_CHN_ID_1)
        Display.show_image(img, alpha = 128)

        img = sensor.snapshot(chn = CAM_CHN_ID_2)
        Display.show_image(img, x = 1920 - 640, layer = Display.LAYER_OSD1)

except KeyboardInterrupt as e:
    print("user stop: ", e)
except BaseException as e:
    print(f"Exception {e}")
finally:
    # 停止sensor
    if isinstance(sensor, Sensor):
        sensor.stop()
    # 销毁display
    Display.deinit()
    os.exitpoint(os.EXITPOINT_ENABLE_SLEEP)
    time.sleep_ms(100)
    # 释放media缓冲区
    MediaManager.deinit()
```

### 2.2 获取双摄图像显示在HDMI显示器

分别配置2个摄像头输出960x540图像，并排显示在HDMI显示器

```python
# Camera 双摄示例
import time, os, sys

from media.sensor import *
from media.display import *
from media.media import *

sensor0 = None
sensor1 = None

try:
    print("camera_test")

    # 按照默认配置构建Sensor对象sensor0
    sensor0 = Sensor(id = 0)
    # sensor0复位
    sensor0.reset()
    # 设置通道0分辨率, 960*540
    sensor0.set_framesize(width = 960, height = 540)
    # 设置通道0格式为YUV420
    sensor0.set_pixformat(Sensor.YUV420SP)
    # 绑定通道0到显示VIDEO1层
    bind_info = sensor0.bind_info(x = 0, y = 0)
    Display.bind_layer(**bind_info, layer = Display.LAYER_VIDEO1)

    # 按照默认配置构建Sensor对象sensor1
    sensor1 = Sensor(id = 1)
    # sensor1复位
    sensor1.reset()
    # 设置通道0分辨率, 960*540
    sensor1.set_framesize(width = 960, height = 540)
    # 设置通道0格式为YUV420
    sensor1.set_pixformat(Sensor.YUV420SP)
    # 绑定通道0到显示VIDEO2层
    bind_info = sensor1.bind_info(x = 960, y = 540)
    Display.bind_layer(**bind_info, layer = Display.LAYER_VIDEO2)

    # 这里设置hdmi和IDE输出显示，如果您选择的屏幕无法点亮，请参考API文档中的K230_CanMV_Display模块API手册自行配置
    Display.init(Display.LT9611, to_ide = True)
    # 初始化media manager
    MediaManager.init()

    # 多摄场景仅需要执行一次run
    sensor0.run()

    while True:
        os.exitpoint()
        time.sleep(1)
except KeyboardInterrupt as e:
    print("user stop")
except BaseException as e:
    print(f"Exception '{e}'")
finally:
    # 多摄场景下，每个sensor都需要执行stop
    if isinstance(sensor0, Sensor):
        sensor0.stop()
    if isinstance(sensor1, Sensor):
        sensor1.stop()
    # 或者执行Sensor.deinit()
    # Sensor.deinit()
    # 销毁 display
    Display.deinit()
    os.exitpoint(os.EXITPOINT_ENABLE_SLEEP)
    time.sleep_ms(100)
    # 释放 media 缓冲区
    MediaManager.deinit()
```

```{admonition} 提示
Sensor模块具体接口请参考[API文档](../../api/mpp/K230_CanMV_Sensor模块API手册.md)
```
